
# Fedora review: http://bugzilla.redhat.com/171504

%define beta rc2

Name:    kipi-plugins
Summary: Plugins to use with Kipi
Version: 0.1.5
Release: 0.6.%{beta}%{?dist}

License: GPLv2+
Group:   Applications/Multimedia
Url:	 http://www.kipi-plugins.org/
Source0: http://downloads.sourceforge.net/sourceforge/kipi/kipi-plugins-%{version}%{?beta:-%{beta}}.tar.bz2
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Patch1: kipi-plugins-0.1.5-rc2-libXrandr.patch

BuildRequires: automake libtool
BuildRequires: gettext
BuildRequires: kdelibs3-devel
BuildRequires: libkipi-devel >= 0.1.5
BuildRequires: libkdcraw-devel >= 0.1.2
BuildRequires: libkexiv2-devel >= 0.1.6
BuildRequires: exiv2-devel 
%if 0%{?fedora} > 6
%define _with_libgpod --with-libgpod
BuildRequires: libgpod-devel >= 0.4.2, glib2-devel
%endif
## slideshow plugin
#BuildRequires: imlib2-devel
## acquireimages, jpeglossless and rawconverter plugins
BuildRequires: libtiff-devel
## kameraklient plugin
BuildRequires: gphoto2-devel 
## htmlexport plugin (libgcrypt is a bogus extra dep from libxslt.la)
BuildRequires: libxml2-devel libxslt-devel libgcrypt-devel 
## calendar plugin (uses libkcal) 
BuildRequires: kdepim-devel

## jpeglossless plugin 
Requires: ImageMagick 

## optional bits
# wallpaper plugin
#Requires(hint): kdebase 
# cdarchiver plugin
#Requires(hint): k3b
%if 0%{?fedora} > 3
# rawconverter plugin 
Requires(hint): dcraw
%endif
# mjpeg plugin 
#Requires(hint): mjpegtools >= 1.6.0

%description
This package contains plugins to use with Kipi, the KDE Image Plugin
Interface.  Currently implemented plugins are:
 * RawConverter       : Raw image converter for digital cameras
 * SlideShow          : Slideshow with effects ripped out from kslideshow
                        and 3D effects using OpenGL
 * MpegEncoder        : Create an MPEG slideshow from your images
                        (requires mjpegtools)
 * PrintWizard:	      : Print multiple images/index pages in one page
 * ImagesGallery      : An HTML gallery generator
 * PrintWizard        : Print images in various format
 * JpegLossLess       : Batch process your JPEG images without losing meta 
                        information and compression
 * CdArchiving        : Archive your albums on CD or DVD (requires k3b)
 * AcquireImages      : Acquire images interface, includes these parts:
                           ScanImages (scanner management using Kooka)
                           ScreenshotImages (Snap Screen based on KSnapshot)
 * Calendar           : Create calendars
 * SendImages         : Send images by email, allowing resizing
                        and recompressing before sending
 * BatchProcessImages : Batch process images: 
                           RenameImages (Image file names renaming)
                           ConvertImages (Image files format converting)
                           BorderImages (Add border to images)
                           FilterImages (Enhancements using digital filters)
                           ColorImages (Image color enhancement)
                           EffectImages (Image transformation effects)
                           ResizeImages (Basic/Prepare-to-print resizing)
                           RecompressImages (Recompress JPEG/TIFF/PNG/TGA)
 * TimeAdjust         : Adjust image file Time and Date
 * WallPaper          : Image to KDE Desktop (requires kdebase)
 * FindImages         : Find dupplicate images in albums
 * GalleryExport      : Export images to a remote Gallery server
                        (http://gallery.sf.net)
 * FlickrExport       : Export images to a remote Flickr web service
                        (http://www.flickr.com)
 * HTMLExport         : Export images collections into HTML page
 * SimpleViewerExport : Export images to SimpleViewer
                         (http://www.airtightinteractive.com/simpleviewer/)
 * GPSSync            : Geolocalize pictures.
%if "%{?_with_libgpod:1}" == "1"
 * IpodExport         : Export pictures with an Ipod device
%endif
 * MetadataEdit       : Edit EXIF and IPTC pictures metadata
 * PicasaWebExport    : Export pictures to Picasa web service


%prep
%setup -q -n %{name}-%{version}%{?beta:-%{beta}}

%patch1 -p1 -b .libXrandr

make -f admin/Makefile.common


%build
unset QTDIR || : ; . /etc/profile.d/qt.sh

%configure \
  --disable-rpath \
  --enable-new-ldflags \
  --disable-debug --disable-warnings \
  --disable-dependancy-tracking --disable-final \
  --with-opengl

make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT

make install DESTDIR=$RPM_BUILD_ROOT

## File lists
# HTML (1.0)
HTML_DIR=$(kde-config --expandvars --install html)
if [ -d $RPM_BUILD_ROOT$HTML_DIR ]; then
for lang_dir in $RPM_BUILD_ROOT$HTML_DIR/* ; do
  if [ -d $lang_dir ]; then
    lang=$(basename $lang_dir)
    echo "%lang($lang) $HTML_DIR/$lang/*" >> %{name}.lang
    # replace absolute symlinks with relative ones
    pushd $lang_dir
      for i in *; do
        [ -d $i -a -L $i/common ] && rm -f $i/common && ln -sf ../common $i/common
      done
    popd
  fi
done
fi
# locale's
for app_file in $RPM_BUILD_ROOT%{_datadir}/locale/*/LC_MESSAGES/*.mo ; do
   app=$(basename $app_file .mo)
   # don't repeat
   [ ! -f ${app}.lang ] && %find_lang ${app}
done

cat *.lang > %{name}-all.lang

## unpackaged files
rm -f $RPM_BUILD_ROOT%{_libdir}/lib*.{la,so}


%clean
rm -rf $RPM_BUILD_ROOT


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files -f %{name}-all.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog README TODO
%{_bindir}/*
%{_libdir}/lib*.so.*
%{_libdir}/kde3/kipiplugin_*.*
%{_mandir}/man[^3]/*
%{_datadir}/apps/kipi/
%{_datadir}/apps/kipiplugin_*
%{_datadir}/config*/*
%{_datadir}/services/*.desktop


%changelog
* Thu Feb 21 2008 Rex Dieter <rdieter@fedoraproject.org> 0.1.5-0.6.rc2
- libXrandr patch

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.1.5-0.5.rc2
- Autorebuild for GCC 4.3

* Sat Feb 02 2008 Rex Dieter <rdieter@fedoraproject.org> 0.1.5-0.4.rc2
- kipi-plugins-0.1.5-rc2

* Sun Dec 30 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.5-0.3.rc1
- kipi-plugins-0.1.5-rc1

* Sat Dec 08 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.5-0.2.beta1
- BR: kdelibs3-devel 

* Wed Nov 21 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.5-0.1.beta1
- kipi-plugins-0.1.5-beta1
- cleanup %%description

* Wed Nov 21 2007 Todd Zullinger <tmz@pobox.com> 0.1.4-5
- rebuild against libgpod-0.6.0

* Wed Sep 19 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.4-4
- rebuild against libkdcraw libkexiv2

* Sat Aug 25 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.4-3
- License: GPLv2+

* Tue Aug 21 2007 Todd Zullinger <tmz@pobox.com> 0.1.4-2
- rebuild against libgpod-0.5.2

* Mon Jul 02 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.4-1
- kipi-plugins-0.1.4(final)

* Wed Jun 20 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.4-0.5.beta3
- LIB_KIO.patch

* Wed Jun 20 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.4-0.4.beta2
- --disable-final

* Tue Jun 19 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.4-0.3.beta2
- BR: libkdcraw-devel >= 0.1.1

* Tue Jun 19 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.4-0.2.beta2
- kipi-plugins-0.1.4-beta2

* Tue Jun 05 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.4-0.1.beta1
- kipi-plugins-0.1.4-beta1

* Mon May 14 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.3-5
- respin against libkexiv2-0.1.5

* Tue May 01 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.3-4
- --with-libgpod (with patch)

* Mon Apr 25 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.3-3
- respin against exiv2-0.14

* Wed Jan 24 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.3-2
- drop --with-libgpod, still busted

* Wed Jan 24 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.3-1
- kipi-plugins-0.1.3
- --with-libgpod 

* Wed Dec 27 2006 Rex Dieter <rdieter[AT]fedoraproject.org> 0.1.3-0.2.rc1
- kipi-plugins-0.1.3-rc1

* Mon Dec 04 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.3-0.1.beta1
- kipi-plugins-0.1.3-beta1

* Wed Oct 25 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.2-2
- rebuild against new(er) imlib2

* Tue Aug 29 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.2-1
- kipi-plugins-0.1.2

* Thu Jun 29 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.1-1
- kipi-plugins-0.1.1

* Sun Jun 25 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-1
- kipi-plugins-0.1.0 (final)

* Fri Jun 23 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.11
- 0.1.0 (final rc candidate)

* Wed May 31 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.10.rc2
- --with-opengl, BR: libGLU-devel
  to ensure build/inclusion of slideshow plugin (#193676)

* Wed May 24 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.9.rc2
- Requires(hint): dcraw

* Mon May 22 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.8.rc2
- 0.1.0-rc2
- BR: ImageMagick-c++-devel, libtiff-devel, libxslt-devel

* Tue Apr 18 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.7.rc1
- fc5: drop gphoto2 workaround (#183262)
- cleanup filelist

* Fri Feb 10 2006 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.6.rc1
- BR: libGL-devel
- fc5: gcc/glibc respin
- fc5: workaround gphoto2 bug (#183367)

* Thu Nov 10 2005 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.5.rc1
- fix symlinks
- simplify configure

* Fri Nov 04 2005 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.4.rc1
- drop redundant %%doc
- simplify BR's

* Sun Oct 23 2005 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.3.rc1
- drop BR: libacl-devel
- drop reference(s) to external repos (legalities)

* Sat Oct 22 2005 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-0.2.rc1
- BR: libacl-devel (at least until kdelibs bug #170602 is fixed)
- drop all optional Req's, mention in %%description
- Release < 1, since it's not final
- %%description: format < 80 columns
- drop goofy install-strip conditional

* Mon Sep 26 2005 Rex Dieter <rexdieter[AT]users.sf.net> 0.1.0-1.rc1
- 0.1.0-rc1

* Tue Feb 08 2005 Rex Dieter <rexdieter[AT]users.sf.net> 0:0.1-0.fdr.0.4.beta2
- 0.1.0-beta2

* Mon Jan 03 2005 Rex Dieter <rexdieter[AT]users.sf.net> 0:0.1-0.fdr.0.3.beta1
- rawconverter: Req: dcraw
- Req: mjpegtools
- Req: ImageMagick 

* Mon Dec 21 2004 Rex Dieter <rexdieter[AT]users.sf.net> 0:0.1-0.fdr.0.2.beta1
- rebuild against libkexif-0.2

* Mon Oct 25 2004 Aurelien Bompard <gauret[AT]free.fr> 0:0.1-0.fdr.0.1.beta1
- Initial RPM release.
